==========
User Guide
==========

.. toctree::
    :hidden:

    why.rst
    installation.rst
    usage.rst
    examples.rst
    contrib/index.rst
    api/index.rst
    faq.rst


This guide describes how to install and use Espresso, and provides :doc:`detailed information <contrib/index>` about individal test problems. You may also wish to look at:

- The :doc:`../contributor_guide/index`, which explains how you can add a new test problem into Espresso, or improve an existing one;
- The :doc:`../developer_guide/index`, which describes the infrastructure that runs 'in the background' to build Espresso;
- Our `Github repository <https://github.com/inlab-geo/espresso/>`_ 
- The Espresso community on Slack

